==> nb_utils-3.3.1-nullsafety.tar.gz: lib/src/shared_pref.dart <==
import 'dart:convert';

import 'package:shared_preferences/shared_preferences.dart';

import '../nb_utils.dart';

/// Returns SharedPref Instance
Future<SharedPreferences> getSharedPref() async {
  return await SharedPreferences.getInstance();
}

/// add a String in SharedPref
Future<void> setString(String key, String value) async {
  await getSharedPref().then((pref) {
    pref.setString(key, value);
  });
}

void setStringAsync(String key, String value) {
  assert(sharedPreferences != null);
  sharedPreferences!.setString(key, value);
}

/// add a Int in SharedPref
Future<void> setInt(String key, int value) async {
  await getSharedPref().then((pref) {
    pref.setInt(key, value);
  });
}

void setIntAsync(String key, int value) {
  assert(sharedPreferences != null);
  sharedPreferences!.setInt(key, value);
}

/// add a Bool in SharedPref
Future<void> setBool(String key, bool value) async {
  await getSharedPref().then((pref) {
    pref.setBool(key, value);
  });
}

void setBoolAsync(String key, bool value) {
  assert(sharedPreferences != null);
  sharedPreferences!.setBool(key, value);
}

/// add a Double in SharedPref
Future<void> setDouble(String key, double value) async {
  await getSharedPref().then((pref) {
    pref.setDouble(key, value);
  });
}

void setDoubleAsync(String key, double value) {
  assert(sharedPreferences != null);
  sharedPreferences!.setDouble(key, value);
}

/// Returns a String if exists in SharedPref
Future<String> getString(String key, {defaultValue = ''}) async {
  return await getSharedPref().then((pref) {
    return pref.getString(key) ?? defaultValue;
  });
}

String getStringAsync(String key, {defaultValue = ''}) {
  assert(sharedPreferences != null);
  return sharedPreferences!.getString(key) ?? defaultValue;
}

/// add a JSON in SharedPref
void setJSONAsync(String key, String value) {
  assert(sharedPreferences != null);
  sharedPreferences!.setString(key, jsonEncode(value));
}

/// Returns a JSON if exists in SharedPref
Map<String, dynamic>? getJSONAsync(
  String key, {
  Map<String, dynamic>? defaultValue,
}) {
  assert(sharedPreferences != null);
  if (sharedPreferences!.containsKey(key)) {
    return jsonDecode(sharedPreferences!.getString(key)!);
  } else {
    return defaultValue ?? {};
  }
}

/// Returns a Int if exists in SharedPref
Future<int> getInt(String key, {defaultValue = 0}) async {
  return await getSharedPref().then((pref) {
    return pref.getInt(key) ?? defaultValue;
  });
}

int getIntAsync(String key, {defaultValue = 0}) {
  assert(sharedPreferences != null);
  return sharedPreferences!.getInt(key) ?? defaultValue;
}

/// Returns a Double if exists in SharedPref
Future<double> getDouble(String key, {defaultValue = 0.0}) async {
  return await getSharedPref().then((pref) {
    return pref.getDouble(key) ?? defaultValue;
  });
}

double getDoubleAsync(String key, {defaultValue = 0.0}) {
  assert(sharedPreferences != null);
  return sharedPreferences!.getDouble(key) ?? defaultValue;
}

/// Returns a Bool if exists in SharedPref
Future<bool> getBool(String key, {defaultValue = false}) async {
  return await getSharedPref().then((pref) {
    return pref.getBool(key) ?? defaultValue;
  });
}

bool getBoolAsync(String key, {defaultValue = false}) {
  assert(sharedPreferences != null);
  return sharedPreferences!.getBool(key) ?? defaultValue;
}

/// remove key from SharedPref
Future<bool> removeKey(String key) async {
  assert(sharedPreferences != null);
  return await sharedPreferences!.remove(key);
}

/// clear SharedPref
Future<bool> clearSharedPref() async {
  assert(sharedPreferences != null);
  return await sharedPreferences!.clear();
}

==> nb_utils-3.3.4-nullsafety.tar.gz: lib/src/shared_pref.dart <==
import 'dart:convert';

import 'package:shared_preferences/shared_preferences.dart';

import '../nb_utils.dart';

/// Returns SharedPref Instance
Future<SharedPreferences> getSharedPref() async {
  return await SharedPreferences.getInstance();
}

/// add a String in SharedPref
Future<void> setString(String key, String value) async {
  await getSharedPref().then((pref) {
    pref.setString(key, value);
  });
}

void setStringAsync(String key, String value) {
  assert(sharedPreferences != null);
  sharedPreferences?.setString(key, value);
}

/// add a Int in SharedPref
Future<void> setInt(String key, int value) async {
  await getSharedPref().then((pref) {
    pref.setInt(key, value);
  });
}

void setIntAsync(String key, int value) {
  assert(sharedPreferences != null);
  sharedPreferences?.setInt(key, value);
}

/// add a Bool in SharedPref
Future<void> setBool(String key, bool value) async {
  await getSharedPref().then((pref) {
    pref.setBool(key, value);
  });
}

void setBoolAsync(String key, bool value) {
  assert(sharedPreferences != null);
  sharedPreferences?.setBool(key, value);
}

/// add a Double in SharedPref
Future<void> setDouble(String key, double value) async {
  await getSharedPref().then((pref) {
    pref.setDouble(key, value);
  });
}

void setDoubleAsync(String key, double value) {
  assert(sharedPreferences != null);
  sharedPreferences?.setDouble(key, value);
}

/// Returns a String if exists in SharedPref
Future<String> getString(String key, {defaultValue = ''}) async {
  return await getSharedPref().then((pref) {
    return pref.getString(key) ?? defaultValue;
  });
}

String getStringAsync(String key, {defaultValue = ''}) {
  assert(sharedPreferences != null);
  return sharedPreferences?.getString(key) ?? defaultValue;
}

/// add a JSON in SharedPref
void setJSONAsync(String key, String value) {
  assert(sharedPreferences != null);
  sharedPreferences?.setString(key, jsonEncode(value));
}

/// Returns a JSON if exists in SharedPref
Map<String, dynamic> getJSONAsync(
  String key, {
  Map<String, dynamic>? defaultValue,
}) {
  assert(sharedPreferences != null);

  if (sharedPreferences!.containsKey(key)) {
    return jsonDecode(sharedPreferences!.getString(key).validate());
  } else {
    return defaultValue ?? {};
  }
}

/// Returns a Int if exists in SharedPref
Future<int> getInt(String key, {defaultValue = 0}) async {
  return await getSharedPref().then((pref) {
    return pref.getInt(key) ?? defaultValue;
  });
}

int getIntAsync(String key, {defaultValue = 0}) {
  assert(sharedPreferences != null);
  return sharedPreferences?.getInt(key) ?? defaultValue;
}

/// Returns a Double if exists in SharedPref
Future<double> getDouble(String key, {defaultValue = 0.0}) async {
  return await getSharedPref().then((pref) {
    return pref.getDouble(key) ?? defaultValue;
  });
}

double getDoubleAsync(String key, {defaultValue = 0.0}) {
  assert(sharedPreferences != null);
  return sharedPreferences?.getDouble(key) ?? defaultValue;
}

/// Returns a Bool if exists in SharedPref
Future<bool> getBool(String key, {defaultValue = false}) async {
  return await getSharedPref().then((pref) {
    return pref.getBool(key) ?? defaultValue;
  });
}

bool getBoolAsync(String key, {defaultValue = false}) {
  assert(sharedPreferences != null);
  return sharedPreferences?.getBool(key) ?? defaultValue;
}

/// remove key from SharedPref
Future<bool> removeKey(String key) async {
  assert(sharedPreferences != null);
  return await sharedPreferences!.remove(key);
}

/// clear SharedPref
Future<bool> clearSharedPref() async {
  assert(sharedPreferences != null);
  return await sharedPreferences!.clear();
}
